<!DOCTYPE html><htmllang="en"><head><metacharset="utf-8"><metaname="viewport"content="width=device-width, initial-scale=1.0"><metaname="generator"content="rustdoc"><metaname="description"content="The type returned by `set_logger` if `set_logger` has already been called."><title>SetLoggerError in log - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../static.files/${f}">`).join(""))</script><linkrel="stylesheet"href="../static.files/normalize-9960930a.css"><linkrel="stylesheet"href="../static.files/rustdoc-84e720fa.css"><metaname="rustdoc-vars"data-root-path="../"data-static-root-path="../static.files/"data-current-crate="log"data-themes=""data-resource-suffix=""data-rustdoc-version="1.89.0 (29483883e 2025-08-04)"data-channel="1.89.0"data-search-js="search-92309212.js"data-settings-js="settings-5514c975.js"><scriptsrc="../static.files/storage-4e99c027.js"></script><scriptdefersrc="sidebar-items.js"></script><scriptdefersrc="../static.files/main-fd3af306.js"></script><noscript><linkrel="stylesheet"href="../static.files/noscript-32bb7600.css"></noscript><linkrel="icon"href="https://www.rust-lang.org/favicon.ico"></head><bodyclass="rustdoc struct"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><navclass="mobile-topbar"><buttonclass="sidebar-menu-toggle"title="show sidebar"></button><aclass="logo-container"href="../log/index.html"><imgsrc="https://www.rust-lang.org/logos/rust-logo-128x128-blk-v2.png"alt=""></a></nav><navclass="sidebar"><divclass="sidebar-crate"><aclass="logo-container"href="../log/index.html"><imgsrc="https://www.rust-lang.org/logos/rust-logo-128x128-blk-v2.png"alt="logo"></a><h2><ahref="../log/index.html">log</a><spanclass="version">0.4.28</span></h2></div><divclass="sidebar-elems"><sectionid="rustdoc-toc"><h2class="location"><ahref="#">SetLogger<wbr>Error</a></h2><h3><ahref="#trait-implementations">Trait Implementations</a></h3><ulclass="block trait-implementation"><li><ahref="#impl-Debug-for-SetLoggerError"title="Debug">Debug</a></li><li><ahref="#impl-Display-for-SetLoggerError"title="Display">Display</a></li></ul><h3><ahref="#synthetic-implementations">Auto Trait Implementations</a></h3><ulclass="block synthetic-implementation"><li><ahref="#impl-Freeze-for-SetLoggerError"title="Freeze">Freeze</a></li><li><ahref="#impl-RefUnwindSafe-for-SetLoggerError"title="RefUnwindSafe">RefUnwindSafe</a></li><li><ahref="#impl-Send-for-SetLoggerError"title="Send">Send</a></li><li><ahref="#impl-Sync-for-SetLoggerError"title="Sync">Sync</a></li><li><ahref="#impl-Unpin-for-SetLoggerError"title="Unpin">Unpin</a></li><li><ahref="#impl-UnwindSafe-for-SetLoggerError"title="UnwindSafe">UnwindSafe</a></li></ul><h3><ahref="#blanket-implementations">Blanket Implementations</a></h3><ulclass="block blanket-implementation"><li><ahref="#impl-Any-for-T"title="Any">Any</a></li><li><ahref="#impl-Borrow%3CT%3E-for-T"title="Borrow<T>">Borrow<T></a></li><li><ahref="#impl-BorrowMut%3CT%3E-for-T"title="BorrowMut<T>">BorrowMut<T></a></li><li><ahref="#impl-From%3CT%3E-for-T"title="From<T>">From<T></a></li><li><ahref="#impl-Into%3CU%3E-for-T"title="Into<U>">Into<U></a></li><li><ahref="#impl-TryFrom%3CU%3E-for-T"title="TryFrom<U>">TryFrom<U></a></li><li><ahref="#impl-TryInto%3CU%3E-for-T"title="TryInto<U>">TryInto<U></a></li></ul></section><divid="rustdoc-modnav"><h2class="in-crate"><ahref="index.html">In crate log</a></h2></div></div></nav><divclass="sidebar-resizer"title="Dragtoresize
</div></details><h2id="trait-implementations"class="section-header">Trait Implementations<ahref="#trait-implementations"class="anchor"></a></h2><divid="trait-implementations-list"><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-Debug-for-SetLoggerError"class="impl"><aclass="src rightside"href="../src/log/lib.rs.html#1543">Source</a><ahref="#impl-Debug-for-SetLoggerError"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Debug.html"title="trait core::fmt::Debug">Debug</a> for <aclass="struct"href="struct.SetLoggerError.html"title="struct log::SetLoggerError">SetLoggerError</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.fmt"class="method trait-impl"><aclass="src rightside"href="../src/log/lib.rs.html#1543">Source</a><ahref="#method.fmt"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Debug.html#tymethod.fmt"class="fn">fmt</a>(&self, f: &mut <aclass="struct"href="https://doc.rust-lang.org/1.89.0/core/fmt/struct.Formatter.html"title="struct core::fmt::Formatter">Formatter</a><'_>) -><aclass="type"href="https://doc.rust-lang.org/1.89.0/core/fmt/type.Result.html"title="type core::fmt::Result">Result</a></h4></section></summary><divclass='docblock'>Formats the value using the given formatter. <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Debug.html#tymethod.fmt">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-Display-for-SetLoggerError"class="impl"><aclass="src rightside"href="../src/log/lib.rs.html#1546-1550">Source</a><ahref="#impl-Display-for-SetLoggerError"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a> for <aclass="struct"href="struct.SetLoggerError.html"title="struct log::SetLoggerError">SetLoggerError</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.fmt-1"class="method trait-impl"><aclass="src rightside"href="../src/log/lib.rs.html#1547-1549">Source</a><ahref="#method.fmt-1"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html#tymethod.fmt"class="fn">fmt</a>(&self, fmt: &mut <aclass="struct"href="https://doc.rust-lang.org/1.89.0/core/fmt/struct.Formatter.html"title="struct core::fmt::Formatter">Formatter</a><'_>) -><aclass="type"href="https://doc.rust-lang.org/1.89.0/core/fmt/type.Result.html"title="type core::fmt::Result">Result</a></h4></section></summary><divclass='docblock'>Formats the value using the given formatter. <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html#tymethod.fmt">Read more</a></div></details></div></details></div><h2id="synthetic-implementations"class="section-header">Auto Trait Implementations<ahref="#synthetic-implementations"class="anchor"></a></h2><divid="synthetic-implementations-list"><sectionid="impl-Freeze-for-SetLoggerError"class="impl"><ahref="#impl-Freeze-for-SetLoggerError"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Freeze.html"title="trait core::marker::Freeze">Freeze</a> for <aclass="struct"href="struct.SetLoggerError.html"title="struct log::SetLoggerError">SetLoggerError</a></h3></section><sectionid="impl-RefUnwindSafe-for-SetLoggerError"class="impl"><ahref="#impl-RefUnwindSafe-for-SetLoggerError"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/panic/unwind_safe/trait.RefUnwindSafe.html"title="trait core::panic::unwind_safe::RefUnwindSafe">RefUnwindSafe</a> for <aclass="struct"href="struct.SetLoggerError.html"title="struct log::SetLoggerError"
<code><ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html"title="trait core::convert::From">From</a><T> for U</code> chooses to do.</p>
</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryFrom%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#813-815">Source</a><ahref="#impl-TryFrom%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html"title="trait core::convert::Into">Into</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error-1"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#817">Source</a><ahref="#associatedtype.Error-1"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"class="associatedtype">Error</a> = <aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/convert/enum.Infallible.html"title="enum core::convert::Infallible">Infallible</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_from"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#820">Source</a><ahref="#method.try_from"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#tymethod.try_from"class="fn">try_from</a>(value: U) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><T, <T as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryInto%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#798-800">Source</a><ahref="#impl-TryInto%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html"title="trait core::convert::TryInto">TryInto</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#802">Source</a><ahref="#associatedtype.Error"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#associatedtype.Error"class="associatedtype">Error</a> = <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_into"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#805">Source</a><ahref="#method.try_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#tymethod.try_into"class="fn">try_into</a>(self) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><U, <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details></div></section></div></main></body></html>